@@ -1,9 +1,9 @@
-# $Id: ODBC.pm 15125 2012-02-03 20:10:24Z mjevans $
+# $Id: ODBC.pm 15160 2012-02-14 21:06:54Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
 # portions Copyright (c) 1997  Thomas K. Wenrich
-# portions Copyright (c) 2007-2011 Martin J. Evans
+# portions Copyright (c) 2007-2012 Martin J. Evans
 #
 # You may distribute under the terms of either the GNU General Public
 # License or the Artistic License, as specified in the Perl README file.
@@ -19,7 +19,7 @@ require 5.008;
 # see discussion on dbi-users at
 # http://www.nntp.perl.org/group/perl.dbi.dev/2010/07/msg6096.html and
 # http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-$DBD::ODBC::VERSION = '1.34_4';
+$DBD::ODBC::VERSION = '1.34_5';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -32,9 +32,9 @@ $DBD::ODBC::VERSION = '1.34_4';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 15125 2012-02-03 20:10:24Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 15160 2012-02-14 21:06:54Z mjevans $, 13,2);
 
-    require_version DBI 1.21;
+    require_version DBI 1.609;
 
     bootstrap DBD::ODBC $VERSION;
 
@@ -630,7 +630,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.34_4.
+This documentation refers to DBD::ODBC version 1.34_5.
 
 =head1 SYNOPSIS
 
@@ -1020,7 +1020,7 @@ into the DBI's system.
 NOTE: calling this method does not clear DBI's error values as usually
 happens.
 
-=head3 odbc_getdiagrec
+=head3 odbc_getdiagfield
 
   $diag = $handle->odbc_getdiagfield($record, $identifier);
 
@@ -1623,6 +1623,8 @@ does this and without this flag you have to add 0 to all bound column
 data returning numbers to get JSON::XS to encode it is N instead of
 "N".
 
+NOTE: For StrictlyTyped you need at least DBI 1.611.
+
 =head3 StrictlyTyped
 
 See DBI's sql_type_cast utility function.
@@ -1638,6 +1640,8 @@ an SQL_INTEGER and the data is not able to be converted to an integer
 the ODBC driver will problably return "Invalid character value for
 cast specification (SQL-22018)".
 
+NOTE: For DiscardString you need at least DBI 1.611.
+
 =head3 TreatAsLOB
 
 See L</odbc_lob_read>.
@@ -2233,7 +2237,7 @@ L<http://www.datadirect.com>
 
 L<http://www.atinet.com>
 
-Some useful tutorials:
+=head2 Some useful tutorials:
 
 Debugging Perl DBI:
 
@@ -2241,7 +2245,6 @@ L<http://www.easysoft.com/developer/languages/perl/dbi-debugging.html>
 
 Enabling ODBC support in Perl with Perl DBI and DBD::ODBC:
 
-
 L<http://www.easysoft.com/developer/languages/perl/dbi_dbd_odbc.html>
 
 Perl DBI/DBD::ODBC Tutorial Part 1 - Drivers, Data Sources and Connection:
@@ -2264,6 +2267,10 @@ Multiple Active Statements (MAS) and DBD::ODBC
 
 L<http://www.easysoft.com/developer/languages/perl/multiple-active-statements.html>
 
+64-bit ODBC
+
+L<http://www.easysoft.com/developer/interfaces/odbc/64-bit.html>
+
 =head2 Frequently Asked Questions
 
 Frequently asked questions are now in L<DBD::ODBC::FAQ>. Run
